'use strict';

/**
 * 基础交互方法
 */

// common接口实现
(function () {
    function ZXApp() {
      this.version = '1.0.0';
    }

    function ZXAppCommon() {
    }

    function getWindows() {
      if (top.window.AppCommonInterface || top.window.AppInterface || top.window.updateToken) {
        return top.window;
      }
      return window;
    }

    ZXAppCommon.prototype = {
        /*-------------------- app信息，用户信息，设备信息 --------------------*/

        /**
         * 获取app版本号
         * @returns {*}
         */
         getAppVersion: function () {
            var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.getAppVersion) {
                return win.AppCommonInterface.getAppVersion();
            } else if (win.AppInterface) {
                return win.AppInterface.getAppVersion();
            } else {
                return win.getAppVersion()
            }
        },

        /**
         * 设置标题
         * @param title
         */
        setTitle: function (title) {
            var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.setTitle) {
              win.AppCommonInterface.setTitle(title);
            } else if (win.AppInterface) {
              win.AppInterface.setTitle(title);
            } else {
              win.zxappSetTitle(title)
            }
        },

        /**
         * 获取当前用户Id
         * @returns {*}
         */
        getUserId: function () {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.getUserId) {
                return win.AppCommonInterface.getUserId();
            } else if (win.AppInterface) {
                return win.AppInterface.getUserId();
            } else {
                return win.zxappGetUserId();
            }
        },

        /**
         * 获取当前token
         * @returns {*}
         */
        getToken: function () {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.getToken) {
                return win.AppCommonInterface.getToken();
            } else if (win.AppInterface) {
                return win.AppInterface.getToken();
            } else {
                return win.zxappGetToken();
            }
        },

        /**
         * 更新token, 更新结束回调 onTokenAccess(success, token)
         */
        updateToken: function () {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.updateToken) {
              win.AppCommonInterface.updateToken();
            } else if (win.AppInterface) {
              win.AppInterface.updateToken();
            } else {
              win.updateToken();
            }
        },

        /**
         * 设置返回类型 0：close, 1: history back, 2: callback
         * @param backType
         * @param callbackMethod
         */
        setGoBackType: function (backType, callbackMethod) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.setGoBackType) {
              win.AppCommonInterface.setGoBackType(backType, callbackMethod);
            } else if (win.AppInterface) {
              win.AppInterface.setGoBackType(backType, callbackMethod);
            } else {
              win.setGoBackType(backType, callbackMethod)
            }
        },

        /**
         * 关闭窗口
         */
        close: function () {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.close) {
              win.AppCommonInterface.close();
            } else if (win.AppInterface) {
              win.AppInterface.close();
            } else {
              win.notifyWindowClose();
            }

        },

        /**
         * 返回, 返回类型可通过setGoBackType方法设置，默认为1
         */
        goBack: function () {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.goBack) {
              win.AppCommonInterface.goBack();
            } else if (win.AppInterface) {
              win.AppInterface.goBack();
            } else {
              win.goBackAction();
            }

        },

        /**
         * 跳转app页面
         * @param internalLink
         */
        productEntry: function (internalLink) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.productEntry) {
              win.AppCommonInterface.productEntry(internalLink);
            } else if (win.AppInterface) {
              win.AppInterface.productEntry(internalLink);
            } else {
              win.productEntry(internalLink)
            }

        },

        /**
         * 新窗口打开链接
         * @param url
         */
        openBrowseWithUrl: function (url) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.openBrowser) {
              win.AppCommonInterface.openBrowser(url);
            } else if (win.AppInterface) {
              win.AppInterface.openBrowser(url);
            } else {
              win.zxappOpenBrowser(url);
            }
        },

        /**
         * 设置导航栏显示状态 0:GONE  1:VISIBLE  2:INVISIBLE
         * @param visibility
         */
        setToolbarVisibility: function (visibility) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.setToolbarVisibility) {
              win.AppCommonInterface.setToolbarVisibility(visibility);
            } else if (win.AppInterface) {
              win.AppInterface.setToolbarVisibility(visibility);
            } else {
              win.setToolbarVisibility(visibility);
            }
        },

        /**
         * 弹出app Toast提示
         * @param text
         */
        showToast: function (text) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.showToast) {
              win.AppCommonInterface.showToast(text);
            } else if (win.AppInterface) {
              win.AppInterface.showToast(text);
            } else {
              win.zxappShowToast(text);
            }
        },

        /**
         * 打开内部浏览器
         * @param url
         * @param title
         */
        openInnerBrowserWithUrlAndTitle: function (url, title) {
          var win = getWindows();
            if(win.AppCommonInterface && win.AppCommonInterface.openInnerBrowser){
              win.AppCommonInterface.openInnerBrowser(url, title);
            }else if (win.AppInterface) {
              win.AppInterface.openInnerBrowser(url, title);
            } else {
              win.zxappOpenInnerBrowser(url, title);
            }
        },

        /**
         * 分享
         * @param type
         * @param title
         * @param content
         * @param targetUrl
         * @param imgUrl
         * @param callback
         */
        share: function (type, title, content, targetUrl, imgUrl, callback) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.share) {
              win.AppCommonInterface.share(type, title, content, targetUrl, imgUrl, callback);
            } else if (win.AppInterface) {
              win.AppInterface.share(type, title, content, targetUrl, imgUrl, callback);
            } else {
              win.setShareAction(type, title, content, targetUrl, imgUrl, callback);
            }


        },

        /*--------------------------新增交互接口------------------------------------*/

        /**
         * 保存图片到相册, iOS只使用url参数  saveImageOfUrlWithName
         * @param url
         * @param imageName
         */
        saveImageWithUrl: function (url, imageName) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.saveImageWithUrl) {
              win.AppCommonInterface.saveImageWithUrl(url, imageName);
            } else if (win.AppInterface) {
              win.AppInterface.saveImageWithUrl(url, imageName);
            } else {
              win.saveImageWithUrl(url, imageName);
            }
        },

        /**
         * 获取网络状态 "wifi"， "wwan" 蜂窝， "none"没有网络
         * @returns {*}
         */
         getNetworkState: function () {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.getNetWorkState) {
                return win.AppCommonInterface.getNetWorkState();
            } else if (win.AppInterface) {
                return win.AppInterface.getNetWorkState();
            } else {
                return win.getNetWorkState();
            }
        },

        /**
         * 打开智批改相机
         * @param parameters
         */
       openMarkingCamera: function (parameters) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.openMarkingCamera) {
              win.AppCommonInterface.openMarkingCamera(parameters);
            } else if (win.AppInterface) {
              win.AppInterface.openMarkingCamera(parameters);
            } else {
              win.launchPhotoEditMarking(parameters);
            }
        },

        /// 处理智批改结果
        /**
         setResult: function (result) {
            var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.setMarkingResult) {
                win.AppCommonInterface.setMarkingResult(result);
            } else {
                win.setResult(result);
            }
        },
         */

        /**
         * 跳转客户端支付
         * @param type
         * @param params
         * @param payFinishedCallback
         */
        zxappPay: function (type, params, payFinishedCallback) {
          var win = getWindows();
            if (win.AppCommonInterface && win.AppCommonInterface.zxappPay) {
              win.AppCommonInterface.zxappPay(type, params, payFinishedCallback);
            } else {
              win.zxappPay(type, params, payFinishedCallback);
            }
        },

        /**
         * 浏览器跳转客户端
         * @param urlScheme
         * @param externalLink
         * @param internalLink
         */
        getUrlScheme: function (urlScheme, externalLink, internalLink) {
          var win = getWindows();
            var urlHost = 'app.zhixue.com?';
            if (internalLink) {
                return urlScheme + urlHost + 'internalLink=' + win.btoa(internalLink);
            } else if (externalLink) {
                return urlScheme + urlHost + 'externalLink=' + win.btoa(externalLink);
            } else {
                return urlScheme;
            }
        },

        saveActionLog: function (module, opCode, otherInfo) {
          var win = getWindows();
          win.AppCommonInterface.saveActionLog(module, opCode, otherInfo);
        }
    };

    ZXApp.prototype.common = new ZXAppCommon()
    window.ZXApp = ZXApp;
})();